==> nextcloud-31.0.10.tgz: nextcloud/apps/twofactor_backupcodes/l10n/pt_BR.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Você criou os códigos de backup de dois fatores para sua conta.",
    "Second-factor backup codes" : "Códigos de backup segundo-fator",
    "Generate backup codes" : "Gerar códigos de backup",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Você ativou a autenticação de dois fatores, mas ainda não gerou códigos de backup. Eles são necessários para restaurar o acesso à sua conta caso você perca seu segundo fator.",
    "Backup code" : "Código de backup",
    "Use backup code" : "Usar o código de backup",
    "Two factor backup codes" : "Códigos de backup de dois fatores",
    "A two-factor auth backup codes provider" : "Um provedor de códigos de backup de autenticação de dois fatores",
    "An error occurred while generating your backup codes" : "Ocorreu um erro ao gerar os códigos de backup",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Códigos de backup foram gerados. Foram usados {used} de um total de {total} códigos.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later." : "Estes são seus códigos de backup. Salve-os e/ou imprima-os, pois você não conseguirá ler os códigos novamente mais tarde.",
    "Save backup codes" : "Salvar códigos de backup",
    "Print backup codes" : "Imprimir códigos de backup",
    "Regenerate backup codes" : "Regerar códigos de backup",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Se você gerar novamente os códigos de backup, invalidará automaticamente os códigos antigos.",
    "{name} backup codes" : "Códigos de backup {name}",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Use um dos códigos de backup que você salvou ao configurar a autenticação de dois fatores.",
    "Submit" : "Enviar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.3.tgz: nextcloud/apps/twofactor_backupcodes/l10n/pt_BR.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Você criou os códigos de backup de dois fatores para sua conta.",
    "Second-factor backup codes" : "Códigos de backup segundo-fator",
    "Generate backup codes" : "Gerar códigos de backup",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Você ativou a autenticação de dois fatores, mas ainda não gerou códigos de backup. Eles são necessários para restaurar o acesso à sua conta caso você perca seu segundo fator.",
    "Backup code" : "Código de backup",
    "Use backup code" : "Usar o código de backup",
    "Two factor backup codes" : "Códigos de backup de dois fatores",
    "A two-factor auth backup codes provider" : "Um provedor de códigos de backup de autenticação de dois fatores",
    "An error occurred while generating your backup codes" : "Ocorreu um erro ao gerar os códigos de backup",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Códigos de backup foram gerados. Foram usados {used} de um total de {total} códigos.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later." : "Estes são seus códigos de backup. Salve-os e/ou imprima-os, pois você não conseguirá ler os códigos novamente mais tarde.",
    "List of backup codes" : "Lista de códigos de backup",
    "Regenerate backup codes" : "Regerar códigos de backup",
    "Print backup codes" : "Imprimir códigos de backup",
    "Save backup codes" : "Salvar códigos de backup",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Se você gerar novamente os códigos de backup, invalidará automaticamente os códigos antigos.",
    "{name} backup codes" : "Códigos de backup {name}",
    "Unable to open a new tab for printing" : "Não é possível abrir uma nova aba para impressão",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Use um dos códigos de backup que você salvou ao configurar a autenticação de dois fatores.",
    "Submit" : "Enviar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
